==> sdx-2.2.2-src.zip: sdx-2.2.2/src/java/fr/gouv/culture/sdx/sitemap/AdminAction.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
/*
 * Created by IntelliJ IDEA.
 * User: fglorieux
 * Date: 24 sept. 2002
 * Time: 21:25:14
 * To change template for new class use
 * Code Style | Class Templates options (Tools | IDE Options).
 */
package fr.gouv.culture.sdx.sitemap;

import fr.gouv.culture.sdx.application.Application;
import fr.gouv.culture.sdx.exception.SDXException;
import fr.gouv.culture.sdx.exception.SDXExceptionCode;
import fr.gouv.culture.sdx.user.UserInformation;
import org.apache.avalon.framework.component.ComponentException;
import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.thread.ThreadSafe;
import org.apache.cocoon.acting.ConfigurableComposerAction;
import org.apache.cocoon.environment.*;

import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;


public class AdminAction extends ConfigurableComposerAction
        implements ThreadSafe {
    fr.gouv.culture.sdx.framework.FrameworkImpl sdx_frame;

    public Map act(Redirector redirector,
                   SourceResolver resolver,
                   Map objectModel,
                   String source,
                   Parameters params) throws ComponentException {
        Map sitemapParams = new HashMap();
        sitemapParams.put("admin", "true");

        if (this.manager == null) {
            SDXException sdxE = new SDXException(null, SDXExceptionCode.ERROR_COMPONENT_MANAGER_NULL, null, null);
            throw new ComponentException(sdxE.getMessage(), null, sdxE);
        }
        try {
            sdx_frame = (fr.gouv.culture.sdx.framework.FrameworkImpl) this.manager.lookup(fr.gouv.culture.sdx.framework.Framework.ROLE);
            if (sdx_frame == null) return null;
            UserInformation sdx_user;
            Request request = ObjectModelHelper.getRequest(objectModel);
            if (request == null) return null;
            Enumeration sdx_enum = new java.util.StringTokenizer(request.getServletPath(), "/");
            String sdx_string = ((java.util.StringTokenizer) sdx_enum).nextToken();
            if (sdx_string == null || "".equals(sdx_string) || "sdx".equals(sdx_string)) return null;
            Application sdx_application = sdx_frame.getApplicationByPath(sdx_string);
            if (sdx_application == null) return null;
            Session session = request.getSession(true);
            if (session == null) return null;
            sdx_user = (UserInformation) session.getAttribute("sdx_user");
            if (sdx_user == null) return null;
            if (sdx_user.isAdmin()) return sitemapParams;
        } catch (Exception e) {
            return null;
        } finally {
            if (sdx_frame != null) manager.release(sdx_frame);
        }
        return null;
    }
}

==> sdx-2.3b1-src.zip: sdx-2.3b1/src/java/fr/gouv/culture/sdx/sitemap/AdminAction.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
/*
 * Created by IntelliJ IDEA.
 * User: fglorieux
 * Date: 24 sept. 2002
 * Time: 21:25:14
 * To change template for new class use
 * Code Style | Class Templates options (Tools | IDE Options).
 */
package fr.gouv.culture.sdx.sitemap;

import fr.gouv.culture.sdx.application.Application;
import fr.gouv.culture.sdx.user.UserInformation;
import fr.gouv.culture.sdx.utils.configuration.ConfigurationUtils;
import org.apache.avalon.framework.component.ComponentException;
import org.apache.avalon.framework.parameters.Parameters;
import org.apache.avalon.framework.thread.ThreadSafe;
import org.apache.cocoon.acting.ConfigurableServiceableAction;
import org.apache.cocoon.environment.*;

import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;


public class AdminAction extends ConfigurableServiceableAction
        implements ThreadSafe {
    fr.gouv.culture.sdx.framework.FrameworkImpl sdx_frame;

    public Map act(Redirector redirector,
                   SourceResolver resolver,
                   Map objectModel,
                   String source,
                   Parameters params) throws ComponentException {
        Map sitemapParams = new HashMap();
        sitemapParams.put("admin", "true");


        try {
            ConfigurationUtils.checkServiceManager(this.manager);
            sdx_frame = (fr.gouv.culture.sdx.framework.FrameworkImpl) this.manager.lookup(fr.gouv.culture.sdx.framework.Framework.ROLE);
            if (sdx_frame == null) return null;
            UserInformation sdx_user;
            Request request = ObjectModelHelper.getRequest(objectModel);
            if (request == null) return null;
            Enumeration sdx_enum = new java.util.StringTokenizer(request.getServletPath(), "/");
            String sdx_string = ((java.util.StringTokenizer) sdx_enum).nextToken();
            if (sdx_string == null || "".equals(sdx_string) || "sdx".equals(sdx_string)) return null;
            Application sdx_application = sdx_frame.getApplicationByPath(sdx_string);
            if (sdx_application == null) return null;
            Session session = request.getSession(true);
            if (session == null) return null;
            sdx_user = (UserInformation) session.getAttribute("sdx_user");
            if (sdx_user == null) return null;
            if (sdx_user.isAdmin()) return sitemapParams;
        } catch (Exception e) {
            return null;
        } finally {
            if (sdx_frame != null) manager.release(sdx_frame);
        }
        return null;
    }
}
